###################################################
### chunk number 1: foo
###################################################
options(keep.source = TRUE, width = 60)
foo <- packageDescription("SPPr")


###################################################
### chunk number 2: functions
###################################################
library(SPPr)
ls("package:SPPr")


###################################################
### chunk number 3: model
###################################################
library(SPPr) # load the library
# require(constants) # permittivity data
# require(baptMisc) # utilities such as clr() to clear the workspace
# clr()

parameters <- list(epsilon = c(1.46^2, -12+1.2i, 1+0i),
		thickness = c(NA, 50, NA), 
		lambda = 632.8, 
		k0 = 2*pi/632.8, 
		anglePrism = pi/3, 
		zeroShift = 0.0, 
		normalisation = 23) # this is the normalisation ratio signal/ref without prism
		
plotModel(parameters, angle=c(-30, 0), add=F, col=2)
title("model")
parameters$thickness[2] <- 35 # change the thickness for fun
plotModel(parameters, angle=c(-30, 0), add=T, col=3, lty=2) # superpose the result


###################################################
### chunk number 4: modelTest
###################################################
library(SPPr) # load the library
# require(constants) # permittivity data
# require(baptMisc) # utilities such as clr() to clear the workspace
# clr()

parameters <- list(epsilon = c(1.46^2, -12+1.2i, 1+0i),
		thickness = c(NA, 50, NA), 
		lambda = 632.8, 
		k0 = 2*pi/632.8, 
		anglePrism = pi/4, 
		zeroShift = 0.0, 
		normalisation = 23) # this is the normalisation ratio signal/ref without prism
		
test <- plotModel(parameters, angle=c(-30, 30), add=F, col=2, ylim=c(0, 1))
title("model with different thicknesses")
criticalEdge(parameters, col=grey(0.5), lty=2)

oneThickness <- function(d, quiet=T, angle=c(-30, 30), add=T, ...){
	
	parameters$thickness[2] <- d
	result <- plotModel(parameters, angle=angle, quiet=quiet, add=add, ...)$R
	result
}
thicknesses <- seq(20, 50, by=10)
results <- sapply(thicknesses, oneThickness)
matlines(test$intAngle, results, lty=2)


###################################################
### chunk number 5: data
###################################################

data(scanSPP) # example of measured data.frame: 
# external angle, signal, reference,  see ?read.table
# typically,  myData <- read.table("myFile.txt") 
# possibly needs some calculations,  such as:
# myData <- within(myData, angle <- - angle / 2 ) 

names(scanSPP) <- c("angle", "signal", "reference")
head(scanSPP) # first few lines,  note the column names

dataNorm <- data2norm(scanSPP,parameters) # this function uses the parameters 
# to calculate the internal angle 
# and normalized intensity
head(dataNorm)

parameters <- list(epsilon = c(1.46^2, -12+1.2i, 1+0i),
		thickness = c(NA, 50, NA), 
		lambda = 632.8, 
		k0 = 2*pi/632.8, 
		anglePrism = pi/3, 
		zeroShift = 0.0, 
		normalisation = 23) 
		
parameters$zeroShift <- -0.1 # manual offset if the zero was not exactly right
dataNorm <- data2norm(scanSPP,parameters)

plotData(dataNorm, internal=TRUE, new=TRUE, col=1, ylim=c(0, 1))
criticalEdge(parameters, col=grey(0.5), lty=2)
title("Data")
		


###################################################
### chunk number 6: fit
###################################################

plotData(dataNorm, internal=TRUE, new=TRUE, col=1, ylim=c(0, 1))
criticalEdge(parameters, col=grey(0.5), lty=2)
title("Data, model, and fit")


plotModel(parameters, angle=dataNorm$extAngle, quiet=F, add=TRUE,col=2)


layer2fit <- 1 # specify which layer is the one to fit
p.ini <- pIni(parameters, layer2fit) 

# result <- optim(p.ini, objF) #  call the optimization routine
# commented to make test run faster
result <- list(par=c(-11.868123 ,   1.279103,   45.340602 ,   1.027804))
yFin <- fitModel(result$par)
yErr<-abs(yFin-dataNorm$N)

 lines(dataNorm$intAngle, yFin, col=3)
# 				
# parameters <- updateParameters(result$par, layer=layer2fit)	
# parameters	
# 
# # fit other layers ...
# layer2fit <- 2
# 		


