library(SPPr)
## basic example for thin film stack ##

my.data <-read.table("bapt.txt", head=TRUE)
## example of measured data.frame:
## extangle, signal, reference,  see ?read.table

## some info
head(my.data)
str(my.data)

## basic plot
with(my.data, plot(angle, signal/reference, type="l"))


parameters <- list(epsilon = c(1.46^2, -12+1.2i,  1+0i),
		thickness = c(NA, 50,   NA), 
		lambda = 632.8, 
		k0 = 2*pi/632.8, 
		anglePrism = pi/3, 
		zeroShift = 0.0, 
		normalisation = 24)

## plot the model
plotModel(parameters, angle=c(-20, 20), add=T, col=2)

## normalise the data
dataNorm <- data2norm(my.data,parameters)
head(dataNorm)

## adjust the zero maybe
parameters$zeroShift <- -0.1
dataNorm <- data2norm(my.data, parameters)

## plot the data
plotData(dataNorm, internal=TRUE, col=1, ylim=c(0, 1))
criticalEdge(parameters, col=grey(0.5), lty=2)

## add the model
plotModel(parameters, angle=dataNorm$extAngle, quiet=F, add=TRUE,col=2)


layer2fit <- 1

## create the initial guess
p.ini <- pIni(parameters, layer2fit)

## minimize the objective function
result <- optim(p.ini, objF)

## calculate the fitted model 
yFin <- fitModel(result$par)
## calculate the error
yErr<-abs(yFin-dataNorm$N)

## plot the fit
lines(dataNorm$intAngle, yFin, col=3)
				
parameters <- updateParameters(result$par, layer=1)		
parameters
## fit other layers ... 

## prettier plot

require(ggplot2)
my.df <- melt(data.frame(angle=Re(dataNorm$intAngle),
                         data=dataNorm$N, model=yFin), id.var="angle")
head(my.df)

test <- Re(criticalEdge(parameters, quiet=T))

p <- 
ggplot(data = my.df, mapping = aes(x = angle, y = value)) + 
  geom_path(mapping=aes(colour=variable)) +
  scale_x_continuous(expression("internal angle / "*degree), lim=c(30, 60)) + 
  scale_y_continuous("normalised reflectivity", lim=c(0, 1)) +  
  scale_colour_brewer(palette="Set1", name="") +
  geom_vline(xintercept=test, linetype=2, color="grey")


print(p)
