library(SPPr)
require(constants)
require(baptMisc)
clr()

####### example of angle scan fitting ######################

data(scanSPP)
head(scanSPP)
# data(parameters) # example values

parameters <- list(epsilon = c(1.46^2, -12+1.2i, 1+0i),
		thickness = c(NA, 50, NA), 
		lambda = 632.8, 
		k0 = 2*pi/632.8, 
		anglePrism = pi/3, 
		zeroShift = -0.4, 
		normalisation = 23)

plotModel(parameters, angle=c(-30, 0),  int=T, plot=T, lines=F, col=2)
		
dataNorm <- data2norm(scanSPP,parameters)
head(dataNorm)

plotData(dataNorm, internal=TRUE,plot=TRUE, col=1, ylim=c(0, 1))
criticalEdge(parameters, col=grey(0.5), lty=2)

layer2fit <- 1


pIni <- pIni(parameters, layer2fit)
plotModel(pIni,layer2fit=1, parameters, angle=dataNorm$extAngle,  int=TRUE, plot=TRUE,lines=T, col=2)

result <- optim(pIni, objF)

yFin <- fitModel(result$par)
yErr<-abs(yFin-dataNorm$N)

plotModel(result$par,layer2fit=1,  parameters, angle=dataNorm$extAngle,  int=TRUE, plot=T,lines=T,  col=3)

############ example of thin film R, T, A at normal incidence #####################

data(AuJChristy)
plot.material("AuJChristy", range=c(0.4, 1), plot=F)->gold
attach(gold)
k0 <- 2*pi/fine.sample$lambda * 1e6
kx <- (0+0i)*k0
thickness <- c(NA, 50, 1e6, NA)*1e-9
epsilon <- matrix(c(1, 1, 1.0, 1), ncol=length(thickness), nrow=length(k0), byrow=T)

epsilon[, 2] <- fine.sample$epsilon
coefs <- reflModel(k0, kx, thickness, epsilon)
R <- Mod(coefs$rr)^2
T <- Mod(coefs$tt)^2
A <- 1-R-T

matplot(fine.sample$lambda, cbind(R, T, A), t="l", col=1:3, lty=1)


############ example of plasmon dispersion plot #####################

data(AuJChristy)
data(AgPalik)

fit.material("AuJChristy", range=c(0.45, 1), draw=F) -> material
fit.material("AgPalik", range=c(0.45, 1), draw=F) -> material

attach(material)
medium.inc <- 1.5
epsilonm <- medium.inc^2
k0 <- 2*pi/fine.sample$lambda * 1e6
cel <- 3e8
#sinAngles <- seq(0.5, 1, length=200)
rangek <- seq(0.5, 1, length=100)
omega <- matrix(k0*cel, ncol=length(rangek), nrow=length(k0), byrow=F)
kx <- outer(medium.inc * k0, sinAngles)

thickness <- c(NA, 30, 1e6, NA)*1e-9
epsilon <- matrix(c(epsilonm, 1, 1.0, 1), ncol=length(thickness), nrow=length(k0), byrow=T)
epsilon[, 2] <- fine.sample$epsilon

oneAngle <- function(kx){
coefs <- reflModel(k0, kx, thickness, epsilon)
R <- Mod(coefs$rr)^2
T <- Mod(coefs$tt)^2
A <- 1-R-T
R
}

apply(kx,2,  oneAngle) -> dispersion
dispersion2 <- log(dispersion - min(dispersion) +1)
omega2 <- omega * 1e-15
kx2 <- kx * 1e-6
plot(omega2~kx2,col=grey(dispersion2/max(dispersion2)),pch=15,cex=.8,
		xlab=expression(paste(k[x], " [", mu*m^-1, "]")),
		ylab=expression(paste(omega, " [rad/s]")))
	
abline(coef=c(0, cel*1e-9), col=2, lty=2, lwd=0.5)

theoDispersion <- k0*1e-6*sqrt((fine.sample$epsilon*1)/(fine.sample$epsilon+1))
colors <- abs(Im(theoDispersion))
points(Re(theoDispersion), k0*1e-15*cel, col = hcl(h=0, alpha= 1-colors/max(colors)), pch=16, cex=0.1)