library(SPPr)
require(constants)
require(baptMisc)
 # clr()


## basic example for thin film stack ##

############ example of plasmon dispersion plot #####################

data(AuJChristy)
data(AgPalik)

fit.material("AuJChristy", range=c(0.45, 1), draw=F)$fine.sample -> material
# plot.material("AgPalik", range=c(0.45, 1), plot=F)$fine.sample -> material


medium.inc <- 1.5
epsilonm <- medium.inc^2
k0 <- 2*pi/material$lambda * 1e6
cel <- 3e8
sinAngles <- seq(0.1, 0.9, length=200)
omega <- matrix(k0*cel, ncol=length(sinAngles), nrow=length(k0), byrow=F)
kx <- outer(medium.inc * k0, sinAngles)

thickness <- c(NA, 30, 1e6, NA)*1e-9
epsilon <- matrix(c(epsilonm, 1, 1.0, 1), ncol=length(thickness), nrow=length(k0), byrow=T)
epsilon[, 2] <- material$epsilon

oneAngle <- function(.kx){
coefs <- reflModel(k0, .kx, thickness, epsilon)
R <- Mod(coefs$rr)^2
T <- Mod(coefs$tt)^2
A <- 1-R-T
R
}

apply(kx,2,  oneAngle) -> dispersion
dispersion2 <- log(dispersion - min(dispersion) +1)
omega2 <- omega * 1e-15
kx2 <- kx * 1e-6
# dim(dispersion)
# length(omega2)
sum(is.na(kx))
pdf("../Chapter2Figs/dispersionSPPs.pdf", width=6, height=6)

plot(omega2~kx2,col=grey(dispersion2/max(dispersion2)),pch=15,cex=.8,
		xlab=expression(paste(k[x], " [", mu*m^-1, "]")),
		ylab=expression(paste(omega, " [rad/s]")))
	
abline(coef=c(0, cel*1e-9), col=2, lty=2, lwd=0.5)

theoDispersion <- k0*1e-6*sqrt((material$epsilon*1)/(material$epsilon+1))
colors <- abs(Im(theoDispersion))
points(Re(theoDispersion), k0*1e-15*cel, col = hcl(h=0, alpha= 1-colors/max(colors)), pch=16, cex=0.3)

dev.off()

