library(SPPr)
require(constants)
require(baptMisc)
# clr()

## example for thin film stack ##

data(AuJChristy) # load some permittivity values
gold <- plot.material("AuJChristy", range=c(0.4, 1), plot=F)$fine.sample

# sweeping over some parameters #
thinFilm <- function(d=50, angle=0, material="gold"){
	material <- get(material)
	k0 <- 2*pi/material$lambda * 1e6 # wave number in vaccuum / m 
	theta <- angle * pi/180 # angle of incidence
	kx <- sin(theta)*(1+0i)*k0 # in-plane wave number 
	thickness <- c(NA, d, 1e6, NA)*1e-9 # incident medium (NA),  film(s), outer medium (NA)
	epsilon <- matrix(c(1.0, 1.0, 1.52, 1.333), ncol=length(thickness), nrow=length(k0), byrow=T) # dielectric functions
	epsilon[, 2] <- material$epsilon

	coefs <- reflModel(k0, kx, thickness, epsilon) # computes r and t coefficients 
	R <- Mod(coefs$rr)^2 # intensity
	T <- Mod(coefs$tt)^2
	A <- 1-R-T
as.data.frame(cbind(lambda=material$lambda, angle, d, R, T, A))
}
# uncomment below to get R,  T and A for a film with default parameters
# thinFilm() # default example

parameters <- expand.grid(c(20, 30, 60), c(0, 30, 89))

mapply(thinFilm, d=parameters[, 1],angle=parameters[, 2],  SIMPLIFY=F) -> test
# head(test)
require(reshape)
require(lattice)
require(latticeExtra)

test.molten <- melt(test, id=c("lambda", "angle", "d"))

p <- xyplot(value~lambda|angle*d, data=test.molten, type="l", groups=variable, 
	xlab= expression(wavelength / mu*m), 
	ylab= "normalised intensity", 
	auto.key = list(space = "right", lines=F, cex=0.8,  points=T,   title = "", cex.title = 1))
	
p2 <- useOuterStrips(p, strip=strip.custom(strip.names = c(T, TRUE), strip.levels = c(TRUE, T)), 
				  strip.left=strip.custom(strip.names = c(T, TRUE), strip.levels = c(TRUE, T)))

print(p2)				
				
				